==> grimoirejs-cauldron-4.1.2-beta.tgz: package/lib/buildUtil/generate-exposure.js <==
"use strict";

var _stringify = require("babel-runtime/core-js/json/stringify");

var _stringify2 = _interopRequireDefault(_stringify);

var _regenerator = require("babel-runtime/regenerator");

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require("babel-runtime/helpers/asyncToGenerator");

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var generateConst = function () {
  var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee() {
    var template, cwd, pkgJson, templateArgs, content, dest_path;
    return _regenerator2.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.prev = 0;
            _context.next = 3;
            return (0, _asyncHelper.templateCompileAsync)(_path2.default.normalize(__dirname + "/../../src/buildUtil/metaInfo-template.template"));

          case 3:
            template = _context.sent;
            cwd = process.cwd();
            _context.t0 = JSON;
            _context.next = 8;
            return (0, _asyncHelper.readFileAsync)(_path2.default.join(cwd, "package.json"));

          case 8:
            _context.t1 = _context.sent;
            pkgJson = _context.t0.parse.call(_context.t0, _context.t1);
            templateArgs = {
              version: pkgJson.version,
              name: pkgJson.name
            };
            content = template(templateArgs);
            dest_path = _path2.default.resolve(_path2.default.join(_path2.default.dirname(_path2.default.join(cwd, _yargs.argv.dest)), "metaInfo.ts"));
            _context.next = 15;
            return (0, _asyncHelper.existsAsync)(dest_path);

          case 15:
            _context.t2 = !_context.sent;

            if (_context.t2) {
              _context.next = 22;
              break;
            }

            _context.t3 = content;
            _context.next = 20;
            return (0, _asyncHelper.readFileAsync)(dest_path);

          case 20:
            _context.t4 = _context.sent;
            _context.t2 = _context.t3 !== _context.t4;

          case 22:
            if (!_context.t2) {
              _context.next = 25;
              break;
            }

            _context.next = 25;
            return (0, _asyncHelper.writeFileAsync)(dest_path, content);

          case 25:
            _context.next = 30;
            break;

          case 27:
            _context.prev = 27;
            _context.t5 = _context["catch"](0);

            console.log(_context.t5);

          case 30:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, this, [[0, 27]]);
  }));

  return function generateConst() {
    return _ref.apply(this, arguments);
  };
}();

var generateIndex = function () {
  var _ref2 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee2() {
    var cwd, pkgJson, projectSuffix, destFileLocation, mainFileLocation, metaInfoLocation, basePath, detectedFiles, pathMap, interfaces, i, relative, absolute, content, key, separated, keyPath, structureObject, _keyPath, jsonCode, objectCode, imports, _keyPath2, templateArgs, index_ts_content, dest_path;

    return _regenerator2.default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.prev = 0;
            _context2.next = 3;
            return (0, _asyncHelper.templateCompileAsync)(_path2.default.normalize(__dirname + "/../../src/buildUtil/index-template.template"));

          case 3:
            indexGen = _context2.sent;
            cwd = process.cwd();
            _context2.t0 = JSON;
            _context2.next = 8;
            return (0, _asyncHelper.readFileAsync)(_path2.default.join(cwd, "package.json"));

          case 8:
            _context2.t1 = _context2.sent;
            pkgJson = _context2.t0.parse.call(_context2.t0, _context2.t1);
            projectSuffix = _yargs.argv.core ? "core" : (0, _common.getSuffix)(pkgJson.name);
            destFileLocation = _path2.default.resolve(_path2.default.join(cwd, _yargs.argv.dest));
            mainFileLocation = _path2.default.resolve(_path2.default.join(cwd, _yargs.argv.main));
            metaInfoLocation = _path2.default.resolve(_path2.default.join(_path2.default.dirname(_path2.default.join(cwd, _yargs.argv.dest)), "metaInfo.ts"));
            basePath = _path2.default.join(cwd, _yargs.argv.src); // absolute path of source directory

            _context2.next = 17;
            return (0, _asyncHelper.globAsync)(_path2.default.join(cwd, _yargs.argv.src, _yargs.argv.ts ? "**/*.ts" : "**/*.js"));

          case 17:
            detectedFiles = _context2.sent;
            // glob all javascript files
            if (_yargs.argv.debug) {
              console.log(_chalk2.default.cyan("CWD:" + cwd + " Project Suffix:" + projectSuffix + "\n destination:" + destFileLocation + "\n mainFile:" + mainFileLocation + "\n basePath:" + basePath + "\n\n DetectedFiles:\n" + detectedFiles));
            }
            pathMap = {};
            interfaces = [];
            // listup files containing `export default`

            i = 0;

          case 22:
            if (!(i < detectedFiles.length)) {
              _context2.next = 39;
              break;
            }

            relative = _path2.default.relative(basePath, detectedFiles[i]);
            absolute = _path2.default.resolve(detectedFiles[i]);

            if (!(destFileLocation === absolute || mainFileLocation === absolute || metaInfoLocation === absolute || /\.d\.ts$/.test(absolute))) {
              _context2.next = 27;
              break;
            }

            return _context2.abrupt("continue", 36);

          case 27:
            _context2.next = 29;
            return (0, _asyncHelper.readFileAsync)(detectedFiles[i]);

          case 29:
            content = _context2.sent;

            if (!(content.indexOf("interface ") >= 0 && content.indexOf("class ") < 0)) {
              _context2.next = 35;
              break;
            }

            // to ignore interfaces
            interfaces.push(relative);
            return _context2.abrupt("continue", 36);

          case 35:
            pathMap[relative] = _path2.default.parse(relative);

          case 36:
            i++;
            _context2.next = 22;
            break;

          case 39:
            if (_yargs.argv.debug) {
              console.log(_chalk2.default.cyan("Target files:\n"));
              for (key in pathMap) {
                console.log(_chalk2.default.cyan(key + " : \"" + pathMap[key] + "\""));
              }
            }
            // separate relative path by '/' or '\'
            separated = {};

            for (keyPath in pathMap) {
              separated[keyPath] = pathMap[keyPath].dir.split(_path2.default.sep);
              separated[keyPath].push(pathMap[keyPath].name); // last element of separated[path] is file name without extension
            }
            // make structure of index
            structureObject = {};

            for (_keyPath in separated) {
              generateStructureRecursively(structureObject, separated[_keyPath], "");
            }
            jsonCode = (0, _stringify2.default)(structureObject, null, "  ");
            objectCode = asJSIndex(jsonCode, separated);
            imports = [];

            for (_keyPath2 in separated) {
              imports.push({
                path: "./" + _keyPath2.replace(/\.js|\.ts/g, ""),
                key: (0, _common.jsSafeString)(separated[_keyPath2].reduce(function (p, c) {
                  return p + c;
                }))
              });
            }
            templateArgs = {
              exportObject: objectCode,
              importCore: _yargs.argv.core ? "" : 'import gr from "grimoirejs";',
              registerNamespace: _yargs.argv.core ? "" : "gr.notifyRegisteringPlugin(__META__.__NAMESPACE__);",
              imports: imports,
              mainPath: "./" + _path2.default.relative(basePath, mainFileLocation).replace(/\.ts|\.js/g, ""),
              registerCode: "(window as any)[\"GrimoireJS\"].lib." + projectSuffix + " = __EXPOSE__;",
              version: pkgJson.version,
              name: pkgJson.name
            };
            index_ts_content = indexGen(templateArgs);
            dest_path = _path2.default.join(cwd, _yargs.argv.dest);
            _context2.next = 53;
            return (0, _asyncHelper.existsAsync)(dest_path);

          case 53:
            _context2.t2 = !_context2.sent;

            if (_context2.t2) {
              _context2.next = 60;
              break;
            }

            _context2.t3 = index_ts_content;
            _context2.next = 58;
            return (0, _asyncHelper.readFileAsync)(dest_path);

          case 58:
            _context2.t4 = _context2.sent;
            _context2.t2 = _context2.t3 !== _context2.t4;

          case 60:
            if (!_context2.t2) {
              _context2.next = 63;
              break;
            }

            _context2.next = 63;
            return (0, _asyncHelper.writeFileAsync)(dest_path, index_ts_content);

          case 63:
            _context2.next = 68;
            break;

          case 65:
            _context2.prev = 65;
            _context2.t5 = _context2["catch"](0);

            console.log(_context2.t5);

          case 68:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2, this, [[0, 65]]);
  }));

  return function generateIndex() {
    return _ref2.apply(this, arguments);
  };
}();

var _asyncHelper = require("../async-helper");

var _yargs = require("yargs");

var _path = require("path");

var _path2 = _interopRequireDefault(_path);

var _chalk = require("chalk");

var _chalk2 = _interopRequireDefault(_chalk);

var _common = require("./common");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var indexGen = void 0;

function generateStructureRecursively(obj, sepDirs, basePath) {
  if (sepDirs.length < 2) {
    return;
  }
  if (sepDirs[0] === '') {
    obj[sepDirs[1]] = (0, _common.jsSafeString)(basePath + sepDirs[1]);
    return;
  }
  basePath = basePath + sepDirs[0];
  if (sepDirs[0] !== '' && obj[sepDirs[0]] === void 0) {
    obj[sepDirs[0]] = {};
  }
  if (sepDirs.length > 2) {
    generateStructureRecursively(obj[sepDirs[0]], sepDirs.slice(1), basePath);
  } else if (sepDirs.length === 2) {
    obj[sepDirs[0]][sepDirs[1]] = (0, _common.jsSafeString)(basePath + sepDirs[1]);
  }
}

function asJSIndex(jsonStr, sepDirs) {
  for (var pathKey in sepDirs) {
    var keyName = (0, _common.jsSafeString)(sepDirs[pathKey].reduce(function (p, c) {
      return p + c;
    }));
    var regex = new RegExp("(: *)\"" + keyName + "\"");
    jsonStr = jsonStr.replace(regex, "$1" + keyName);
  }
  return jsonStr;
}

(0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee3() {
  return _regenerator2.default.wrap(function _callee3$(_context3) {
    while (1) {
      switch (_context3.prev = _context3.next) {
        case 0:
          _context3.next = 2;
          return generateIndex();

        case 2:
          _context3.next = 4;
          return generateConst();

        case 4:
        case "end":
          return _context3.stop();
      }
    }
  }, _callee3, this);
}))();

==> grimoirejs-cauldron-4.1.6-beta.tgz: package/lib/buildUtil/generate-exposure.js <==
"use strict";

var _stringify = require("babel-runtime/core-js/json/stringify");

var _stringify2 = _interopRequireDefault(_stringify);

var _regenerator = require("babel-runtime/regenerator");

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require("babel-runtime/helpers/asyncToGenerator");

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var generateConst = function () {
  var _ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee() {
    var template, cwd, pkgJson, templateArgs, content, dest_path;
    return _regenerator2.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.prev = 0;
            _context.next = 3;
            return (0, _asyncHelper.templateCompileAsync)(_path2.default.normalize(__dirname + "/../../src/buildUtil/metaInfo-template.template"));

          case 3:
            template = _context.sent;
            cwd = process.cwd();
            _context.t0 = JSON;
            _context.next = 8;
            return (0, _asyncHelper.readFileAsync)(_path2.default.join(cwd, "package.json"));

          case 8:
            _context.t1 = _context.sent;
            pkgJson = _context.t0.parse.call(_context.t0, _context.t1);
            templateArgs = {
              version: pkgJson.version,
              name: pkgJson.name
            };
            content = template(templateArgs);
            dest_path = _path2.default.resolve(_path2.default.join(_path2.default.dirname(_path2.default.join(cwd, _yargs.argv.dest)), "metaInfo.ts"));
            _context.next = 15;
            return (0, _asyncHelper.existsAsync)(dest_path);

          case 15:
            _context.t2 = !_context.sent;

            if (_context.t2) {
              _context.next = 22;
              break;
            }

            _context.t3 = content;
            _context.next = 20;
            return (0, _asyncHelper.readFileAsync)(dest_path);

          case 20:
            _context.t4 = _context.sent;
            _context.t2 = _context.t3 !== _context.t4;

          case 22:
            if (!_context.t2) {
              _context.next = 25;
              break;
            }

            _context.next = 25;
            return (0, _asyncHelper.writeFileAsync)(dest_path, content);

          case 25:
            _context.next = 30;
            break;

          case 27:
            _context.prev = 27;
            _context.t5 = _context["catch"](0);

            console.log(_context.t5);

          case 30:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, this, [[0, 27]]);
  }));

  return function generateConst() {
    return _ref.apply(this, arguments);
  };
}();

var generateIndex = function () {
  var _ref2 = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee2() {
    var cwd, pkgJson, projectSuffix, destFileLocation, mainFileLocation, metaInfoLocation, basePath, detectedFiles, pathMap, i, relative, absolute, content, key, separated, keyPath, structureObject, _keyPath, jsonCode, objectCode, imports, _keyPath2, templateArgs, index_ts_content, dest_path;

    return _regenerator2.default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.prev = 0;
            _context2.next = 3;
            return (0, _asyncHelper.templateCompileAsync)(_path2.default.normalize(__dirname + "/../../src/buildUtil/index-template.template"));

          case 3:
            indexGen = _context2.sent;
            cwd = process.cwd();
            _context2.t0 = JSON;
            _context2.next = 8;
            return (0, _asyncHelper.readFileAsync)(_path2.default.join(cwd, "package.json"));

          case 8:
            _context2.t1 = _context2.sent;
            pkgJson = _context2.t0.parse.call(_context2.t0, _context2.t1);
            projectSuffix = _yargs.argv.core ? "core" : (0, _common.getSuffix)(pkgJson.name);
            destFileLocation = _path2.default.resolve(_path2.default.join(cwd, _yargs.argv.dest));
            mainFileLocation = _path2.default.resolve(_path2.default.join(cwd, _yargs.argv.main));
            metaInfoLocation = _path2.default.resolve(_path2.default.join(_path2.default.dirname(_path2.default.join(cwd, _yargs.argv.dest)), "metaInfo.ts"));
            basePath = _path2.default.join(cwd, _yargs.argv.src); // absolute path of source directory

            _context2.next = 17;
            return (0, _asyncHelper.globAsync)(_path2.default.join(cwd, _yargs.argv.src, _yargs.argv.ts ? "**/*.ts" : "**/*.js"));

          case 17:
            detectedFiles = _context2.sent;
            // glob all javascript files
            if (_yargs.argv.debug) {
              console.log(_chalk2.default.cyan("CWD:" + cwd + " Project Suffix:" + projectSuffix + "\n destination:" + destFileLocation + "\n mainFile:" + mainFileLocation + "\n basePath:" + basePath + "\n\n DetectedFiles:\n" + detectedFiles));
            }
            pathMap = {};
            // listup files containing `export default`

            i = 0;

          case 21:
            if (!(i < detectedFiles.length)) {
              _context2.next = 33;
              break;
            }

            relative = _path2.default.relative(basePath, detectedFiles[i]);
            absolute = _path2.default.resolve(detectedFiles[i]);

            if (!(destFileLocation === absolute || mainFileLocation === absolute || metaInfoLocation === absolute || /\.d\.ts$/.test(absolute))) {
              _context2.next = 26;
              break;
            }

            return _context2.abrupt("continue", 30);

          case 26:
            _context2.next = 28;
            return (0, _asyncHelper.readFileAsync)(detectedFiles[i]);

          case 28:
            content = _context2.sent;

            pathMap[relative] = _path2.default.parse(relative);

          case 30:
            i++;
            _context2.next = 21;
            break;

          case 33:
            if (_yargs.argv.debug) {
              console.log(_chalk2.default.cyan("Target files:\n"));
              for (key in pathMap) {
                console.log(_chalk2.default.cyan(key + " : \"" + pathMap[key] + "\""));
              }
            }
            // separate relative path by '/' or '\'
            separated = {};

            for (keyPath in pathMap) {
              separated[keyPath] = pathMap[keyPath].dir.split(_path2.default.sep);
              separated[keyPath].push(pathMap[keyPath].name); // last element of separated[path] is file name without extension
            }
            // make structure of index
            structureObject = {};

            for (_keyPath in separated) {
              generateStructureRecursively(structureObject, separated[_keyPath], "");
            }
            jsonCode = (0, _stringify2.default)(structureObject, null, "  ");
            objectCode = asJSIndex(jsonCode, separated);
            imports = [];

            for (_keyPath2 in separated) {
              imports.push({
                path: "./" + _keyPath2.replace(/\.js|\.ts/g, ""),
                key: (0, _common.jsSafeString)(separated[_keyPath2].reduce(function (p, c) {
                  return p + c;
                }))
              });
            }
            templateArgs = {
              exportObject: objectCode,
              importCore: _yargs.argv.core ? "" : 'import gr from "grimoirejs";',
              registerNamespace: _yargs.argv.core ? "" : "gr.notifyRegisteringPlugin(__META__.__NAMESPACE__);",
              imports: imports,
              mainPath: "./" + _path2.default.relative(basePath, mainFileLocation).replace(/\.ts|\.js/g, ""),
              registerCode: "(window as any)[\"GrimoireJS\"].lib." + projectSuffix + " = __EXPOSE__;",
              version: pkgJson.version,
              name: pkgJson.name
            };
            index_ts_content = indexGen(templateArgs);
            dest_path = _path2.default.join(cwd, _yargs.argv.dest);
            _context2.next = 47;
            return (0, _asyncHelper.existsAsync)(dest_path);

          case 47:
            _context2.t2 = !_context2.sent;

            if (_context2.t2) {
              _context2.next = 54;
              break;
            }

            _context2.t3 = index_ts_content;
            _context2.next = 52;
            return (0, _asyncHelper.readFileAsync)(dest_path);

          case 52:
            _context2.t4 = _context2.sent;
            _context2.t2 = _context2.t3 !== _context2.t4;

          case 54:
            if (!_context2.t2) {
              _context2.next = 57;
              break;
            }

            _context2.next = 57;
            return (0, _asyncHelper.writeFileAsync)(dest_path, index_ts_content);

          case 57:
            _context2.next = 62;
            break;

          case 59:
            _context2.prev = 59;
            _context2.t5 = _context2["catch"](0);

            console.log(_context2.t5);

          case 62:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2, this, [[0, 59]]);
  }));

  return function generateIndex() {
    return _ref2.apply(this, arguments);
  };
}();

var _asyncHelper = require("../async-helper");

var _yargs = require("yargs");

var _path = require("path");

var _path2 = _interopRequireDefault(_path);

var _chalk = require("chalk");

var _chalk2 = _interopRequireDefault(_chalk);

var _common = require("./common");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var indexGen = void 0;

function generateStructureRecursively(obj, sepDirs, basePath) {
  if (sepDirs.length < 2) {
    return;
  }
  if (sepDirs[0] === '') {
    obj[sepDirs[1]] = (0, _common.jsSafeString)(basePath + sepDirs[1]);
    return;
  }
  basePath = basePath + sepDirs[0];
  if (sepDirs[0] !== '' && obj[sepDirs[0]] === void 0) {
    obj[sepDirs[0]] = {};
  }
  if (sepDirs.length > 2) {
    generateStructureRecursively(obj[sepDirs[0]], sepDirs.slice(1), basePath);
  } else if (sepDirs.length === 2) {
    obj[sepDirs[0]][sepDirs[1]] = (0, _common.jsSafeString)(basePath + sepDirs[1]);
  }
}

function asJSIndex(jsonStr, sepDirs) {
  for (var pathKey in sepDirs) {
    var keyName = (0, _common.jsSafeString)(sepDirs[pathKey].reduce(function (p, c) {
      return p + c;
    }));
    var regex = new RegExp("(: *)\"" + keyName + "\"");
    jsonStr = jsonStr.replace(regex, "$1" + keyName);
  }
  return jsonStr;
}

(0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee3() {
  return _regenerator2.default.wrap(function _callee3$(_context3) {
    while (1) {
      switch (_context3.prev = _context3.next) {
        case 0:
          _context3.next = 2;
          return generateIndex();

        case 2:
          _context3.next = 4;
          return generateConst();

        case 4:
        case "end":
          return _context3.stop();
      }
    }
  }, _callee3, this);
}))();
